You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mxnet.apache.org by jx...@apache.org on 2017/08/18 04:20:31 UTC

[incubator-mxnet] branch master updated: Modify pip install to specific tag (#7514)

This is an automated email from the ASF dual-hosted git repository.

jxie pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-mxnet.git


The following commit(s) were added to refs/heads/master by this push:
     new 6004e52  Modify pip install to specific tag (#7514)
6004e52 is described below

commit 6004e529320a3230607ff535d2ec16190130959d
Author: Yao Wang <ke...@gmail.com>
AuthorDate: Thu Aug 17 21:20:29 2017 -0700

    Modify pip install to specific tag (#7514)
    
    * Modify pip installation to specific tag
    
    * Fix
---
 docs/build_version_doc/AddVersion.py | 13 ++++++++++++-
 1 file changed, 12 insertions(+), 1 deletion(-)

diff --git a/docs/build_version_doc/AddVersion.py b/docs/build_version_doc/AddVersion.py
index 4495944..e5569a0 100755
--- a/docs/build_version_doc/AddVersion.py
+++ b/docs/build_version_doc/AddVersion.py
@@ -86,14 +86,25 @@ if __name__ == '__main__':
                 outstr = outstr.replace('http://mxnet.io', 'https://mxnet.incubator.apache.org/'
                                                                'versions/%s' % (args.current_version))
 
-            # Fix git clone to specific tag
+            # Fix git clone and pip installation to specific tag
+            pip_pattern = ['', '-cu80', '-cu75', '-cu80mkl', '-cu75mkl', '-mkl']
             if args.current_version == 'master':
                 outstr = outstr.replace('git clone --recursive https://github.com/dmlc/mxnet',
                                         'git clone --recursive https://github.com/apache/incubator-mxnet.git')
+                for trail in pip_pattern:
+                    outstr = outstr.replace('pip install mxnet%s<' % (trail),
+                                            'pip install mxnet%s --pre<' % (trail))
+                    outstr = outstr.replace('pip install mxnet%s\n<' % (trail),
+                                            'pip install mxnet%s --pre\n<' % (trail))
             else:
                 outstr = outstr.replace('git clone --recursive https://github.com/dmlc/mxnet',
                                         'git clone --recursive https://github.com/apache/incubator-mxnet.git '
                                         '--branch %s' % (args.current_version))
+                for trail in pip_pattern:
+                    outstr = outstr.replace('pip install mxnet%s<' % (trail),
+                                            'pip install mxnet%s==%s<' % (trail, args.current_version))
+                    outstr = outstr.replace('pip install mxnet%s\n<' % (trail),
+                                            'pip install mxnet%s==%s\n<' % (trail, args.current_version))
 
             with open(os.path.join(path, name), "w") as outf:
                 outf.write(outstr)

-- 
To stop receiving notification emails like this one, please contact
['"commits@mxnet.apache.org" <co...@mxnet.apache.org>'].